@@ -35,7 +35,7 @@ var searchData=
   ['formats_2eh_32',['formats.h',['../libcamera_2include_2libcamera_2internal_2formats_8h.html',1,'']]],
   ['fourcc_33',['fourcc',['../classlibcamera_1_1V4L2DeviceFormat.html#a1d9f472f571be3791f70e4cf44daae82',1,'libcamera::V4L2DeviceFormat::fourcc()'],['../classlibcamera_1_1V4L2PixelFormat.html#a79d3f70a7b907efae0804751ef054748',1,'libcamera::V4L2PixelFormat::fourcc()'],['../classlibcamera_1_1PixelFormat.html#ad2a53a4a70756f31280d386550de5f05',1,'libcamera::PixelFormat::fourcc()']]],
   ['framebuffer_34',['FrameBuffer',['../classlibcamera_1_1FrameBuffer.html#a86db89fb9e428357ab05bf71ae72c421',1,'libcamera::FrameBuffer::FrameBuffer(const std::vector&lt; Plane &gt; &amp;planes, unsigned int cookie=0)'],['../classlibcamera_1_1FrameBuffer.html#af5b65931df6a8354f8bb2d932e0b1d72',1,'libcamera::FrameBuffer::FrameBuffer(std::unique_ptr&lt; Private &gt; d)'],['../classlibcamera_1_1FrameBuffer.html',1,'libcamera::FrameBuffer']]],
-  ['framebuffer_2eh_35',['framebuffer.h',['../framebuffer_8h.html',1,'(Global Namespace)'],['../internal_2framebuffer_8h.html',1,'(Global Namespace)']]],
+  ['framebuffer_2eh_35',['framebuffer.h',['../internal_2framebuffer_8h.html',1,'(Global Namespace)'],['../framebuffer_8h.html',1,'(Global Namespace)']]],
   ['framebuffer_5fallocator_2eh_36',['framebuffer_allocator.h',['../framebuffer__allocator_8h.html',1,'']]],
   ['framebufferallocator_37',['FrameBufferAllocator',['../classlibcamera_1_1FrameBufferAllocator.html#ab66590d49bdb5dba848a74604f0b2597',1,'libcamera::FrameBufferAllocator::FrameBufferAllocator()'],['../classlibcamera_1_1FrameBufferAllocator.html',1,'libcamera::FrameBufferAllocator']]],
   ['framecancelled_38',['FrameCancelled',['../structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a1ca4a9a1fbd6225f498e4ab942da1ce4',1,'libcamera::FrameMetadata']]],
